# aiobloom

[![Build Status](https://travis-ci.org/jiamo/aiobloom.svg?branch=master)](https://travis-ci.org/jiamo/aiobloom)
[![Python Version](https://img.shields.io/pypi/pyversions/aiobloom.svg)](https://pypi.python.org/pypi/aiobloom)
[![Version](https://img.shields.io/pypi/v/aiobloom.svg)](https://pypi.python.org/pypi/aiobloom)
[![Format](https://img.shields.io/pypi/format/aiobloom.svg)](https://pypi.python.org/pypi/aiobloom)
[![License](https://img.shields.io/pypi/l/aiobloom.svg)](https://pypi.python.org/pypi/aiobloom)
[![codecov](https://codecov.io/gh/jiamo/aiobloom/branch/master/graph/badge.svg)](https://codecov.io/gh/jiamo/aiobloom)

async api for bloom filter using redis

## Installation

~~~
pip install aiobloom
~~~

## test
~~~
py.test
~~~
